library(testthat)
library(ndi)

test_check('ndi')
